% This codes is used to calculate the main counterfactuals in the paper. It
% uses as inputs text data files: trade_small_3.txt, pwt_small_3.txt, and
% deflator.txt. Its main output is the Matlab data file
% trans_k0_al0_s_02_mu_34_exp_03.mat. Notice that the code calculates
% additional counterfactuals that are neither reported in the paper nor in
% the supplementary appendix. We have decided to keep them as they might be
% of interest to future researchers.

clear all
close all

global ep mu et th bt ga Ga1 Ga2 L N adjust_w adjust_la imax toler

ep=1.01; % epsilon, elasticity of substitution in the intermediate
% aggregate
mu=.34; % mu, fraction of tradable goods
th=4; % theta, curvature of the Frechet distribution
et=0.48; % eta, intermediate input elasticity

adjust_w=.25; % update of the tatonnement process
adjust_la=.1; % update of the tatonnement process

Ga1=gamma(1+(1-ep)/th);

% gdp_type = 1; % output side
gdp_type = 0; % expenditure side


% bilateral trade flows dataset, 4096 (country pairs) x 41 (two country ids
% and 39 periods)
trade=load('trade_small_3.txt');
% trade=load('trade_small_3_reexports_in.txt'); % alternative version where
% reexports were reassigned to initially exporting countries

% Penn World Table data, 2496 (39 years x 64 countries) x 18 variables
pwt=load('pwt_small_3.txt');

% price index of personal consumption expenditure, NIPA table Table 1.1.4.
% p_2005/p_t
temp=load('deflator.txt');
deflator=temp(:,2);

tt=(1962:2000)';
T=length(tt);
N=length(trade(:,1))^.5;

% get indices corresponding to following countries in ii
ii=trade(1:N,2);
iUS=find(trade(1:N,2)==87);
iKorea=find(trade(1:N,2)==47);
iChina=find(trade(1:N,2)==15);
iTaiwan=find(trade(1:N,2)==77);
iThailand=find(trade(1:N,2)==79);
iBelgium=find(trade(1:N,2)==6);
iParaguay=find(trade(1:N,2)==64);
iSpain=find(trade(1:N,2)==72);
iPortugal=find(trade(1:N,2)==67);
iCanada=find(trade(1:N,2)==12);

% create [T,N] matrix for each variable in pwt
pop=reshape(pwt(:,2),T,N)';
emp=reshape(pwt(:,3),T,N)';
hc=reshape(pwt(:,4),T,N)';
gdpr=reshape(pwt(:,6),T,N)'*1000;
% output-side
if gdp_type == 1
    gdpn=reshape(pwt(:,8).*pwt(:,13),T,N)'*1000;
    gdpr0=reshape(pwt(:,8),T,N)'*1000;
    % expenditure-side
else
    gdpn=reshape(pwt(:,14).*pwt(:,15),T,N)'*1000;
    gdpr0=reshape(pwt(:,14),T,N)'*1000;
end
k=reshape(pwt(:,7),T,N)'*1000; % rkna, Capital stock at constant 2005 national prices (in mil. 2005US$)
k0=reshape(pwt(:,9),T,N)'*1000; % ck, Capital stock at current PPPs (in mil. 2005US$)
gdpr=gdpr.*(gdpr0(:,1)*ones(1,T))./(gdpr(:,1)*ones(1,T));
k=k.*(k0(:,1)*ones(1,T))./(k(:,1)*ones(1,T));

% measure of equipped labor normalized by US
ze = 0.36; % capital elasticity
L=k.^(ze).*(emp.*hc).^(1 - ze);


L=L/L(iUS,1);

% Real GDP per Capita normalized by US in 1962
y=(gdpr/gdpr(iUS,1))./L;
% y=(gdpr)./L;

% share of merchandixe imports at current PPP
m_gdp=reshape(pwt(:,10),T,N)';

% price level
% p_data=reshape(pwt(:,13),T,N)'; % pl_gdpo, Price level of CGDPo (PPP/XR),  price level of USA GDPo in 2005=1
% p_data=reshape(pwt(:,15),T,N)'; % pl_gdpe, Price level of CGDPe (PPP/XR),  price level of USA GDPo in 2005=1
p_data=gdpn./gdpr;

Y_data=gdpn./(ones(N,1)*p_data(iUS,:)); % in dollars of 2005
Y_data=Y_data./Y_data(iUS,1);

w_data=Y_data./L;

% US real gdp growth
gUS=log(y(iUS,end)/y(iUS,1))/(T-1);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                calculate trade shares and trade costs                  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

for t=1:T
    temp=reshape(trade(:,t+2),N,N)';
    
    % calculate trade shares
    for i=1:N
        
        for j=1:N
            
            if j==i
                % [(gdpn of country i - sum exports of country i)/
                % (sum imports of country i + gdpn of country i - sum exports of country i)]
                
                PI_data(i,j)=(gdpn(i,t)/(1-et)-sum(temp(:,i)))...
                    /(sum(temp(i,:))-sum(temp(:,i))+gdpn(i,t)/(1-et));
                
            else
                % [(imports to country i from country j)/
                % (sum imports of country i + gdpn of country i - sum exports of country i)]
                PI_data(i,j)=temp(i,j)...
                    /(sum(temp(i,:))-sum(temp(:,i))+gdpn(i,t)/(1-et));
                
            end
            
        end
        
    end
    
    % reshape and store trade shares for each time period
    PI_t(:,t)=reshape(PI_data,N*N,1);
    
    for i=1:N
        % imports, imports/gdpn, exports of country i
        im(i,t)=sum(temp(i,:));
        im_gdpn(i,t)=sum(temp(i,:))/gdpn(i,t);
        ex(i,t)=sum(temp(:,i));
        
        % Approximate Z(i,t) using tradables own share
        [Z(i,t) fZ(i,t)]=fminbnd('eq_Z_pi',0,1,[],PI_data(i,i));
        
        % own  share from data
        pi_ii_data(i,t)=PI_data(i,i);
        
    end
    
    % share of country i's spending on non-tradable goods (see Appendix B)
    PI_NT_t(:,t)=(1-mu)./(1-mu+mu*Z(:,t).^(-(ep-1)/th));
    
    %share of country i's tradable spending on goods from country j
    PI_T=PI_data-diag(PI_NT_t(:,t));
    PI_T_t(:,t)=reshape(PI_T,N*N,1);
    
    % lump-sum transfers required to rationalize non-balance trade
    Trdollars2(:,t)=inv(PI_data')*(gdpn(:,t)/(1-et)-PI_data'*gdpn(:,t)/(1-et));
    
    Trb(:,t)=Trdollars2(:,t)./gdpn(:,t);
    Tr(:,t)=Trdollars2(:,t)/sum(gdpn(:,t));
    
    K0=zeros(N,N);
    
    %     % calibrating symmetric iceberg trade costs
    %      for i=1:N-1
    %
    %          for j=i+1:N
    %
    %              m(i,j)=temp(i,j)/im(i,t);
    %              m(j,i)=temp(j,i)/im(j,t);
    %
    %              K0(i,j)=(m(i,j)*m(j,i)...
    %                  *((1-Z(i,t))/Z(i,t))*((1-Z(j,t))/Z(j,t)))^(-1/(2*th));
    %
    %          end
    %
    %      end
    %
    %
    %     K=K0+K0'+eye(N);
    
    % calculate asymmetric iceberg trade costs (See Section 4.2)
    for i=1:N
        
        for j=1:i-1
            
            % using price information to identify asymmetric trade costs
            K0(i,j)=((1-PI_data(i,i))/PI_data(i,j)*Z(i,t)/(1-Z(i,t)))^(1/th)...
                *p_data(i,t)/p_data(j,t)...
                *((1-mu+mu*Z(i,t)^(-(ep-1)/th))/(1-mu+mu*Z(j,t)^(-(ep-1)/th)))^(1/(ep-1));
            
        end
        
        for j=i+1:N
            
            K0(i,j)=((1-PI_data(i,i))/PI_data(i,j)*Z(i,t)/(1-Z(i,t)))^(1/th)...
                *p_data(i,t)/p_data(j,t)...
                *((1-mu+mu*Z(i,t)^(-(ep-1)/th))/(1-mu+mu*Z(j,t)^(-(ep-1)/th)))^(1/(ep-1));
            
        end
        
    end
    
    K=K0+eye(N);
    
    KK(:,t)=reshape(K,N*N,1);
        
    % calculate the initial stock of knowledge (See Section 4.2)

    if t==1
        
        la0=y(:,1).^((1-et)*th)./(Ga1^(th/(ep-1)).*(1-mu+mu*Z(:,1).^(-(ep-1)/th)).^(th/(ep-1)));
        
        la=la0;
        
    end
    
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%               calibration of \alpha_{it} using calibrated              %
%              trade cost matrix and sequence of lambda_{it}             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% grid of values of beta
gridbt=[0 .1 .25 .4 .5 .6 .7 .75 .9 .95];

Ibt=length(gridbt);
% Ibt=1;

% for each value of beta, calculate the value of gamma required to
% rationalize the average growth of TFP in the US
for ibt=1:Ibt
    
    bt=gridbt(ibt);
    
    Ga2=gamma(1-bt+(1-ep)/th);
    
    % calculate stock of knowledge
    la_temp(:,1)=(y(:,1)).^((1-et)*th)./(Ga1^(th/(ep-1)).*(1-mu+mu*Z(:,1).^(-(ep-1)/th)).^(th/(ep-1)));
    la_temp2(:,1)=la_temp(:,1);
    
    for t=1:T-1
        
        PI=reshape(PI_t(:,t),N,N);
        
        PI_T=reshape(PI_T_t(:,t),N,N);
        
        % calculate stock of knowledge and alpha using law of motion for US
        la_temp(:,t+1)=(y(:,t+1)).^((1-et)*th)./(Ga1^(th/(ep-1)).*(1-mu+mu*Z(:,t+1).^(-(ep-1)/th)).^(th/(ep-1)));
        la_temp2(:,t+1)=la_temp(:,t+1);
        
        alUS(t)=max(0,(la_temp(iUS,t+1)-la_temp2(iUS,t)) ...
            /(Ga2/Ga1)./(PI_NT_t(iUS,t).*la_temp2(iUS,t).^bt...
            +(PI_T(iUS,:)*ones(N,1)).^bt.*(PI_T(iUS,:).^(1-bt)*la_temp2(:,t).^bt)));
        
        la_temp2(iUS,t+1)=Ga2/Ga1*alUS(t).*(PI_NT_t(iUS,t).*la_temp2(iUS,t).^bt...
            +(PI_T(iUS,:)*ones(N,1)).^bt.*(PI_T(iUS,:).^(1-bt)*la_temp2(:,t).^bt))+la_temp2(iUS,t);
        
        
    end
    
    
    ga_high=.1;
    ga_low=.0;
    ga=.5*ga_low+.5*ga_high;
    
    PI=reshape(PI_t(:,1),N,N);
    PI_T=reshape(PI_T_t(:,1),N,N);
    
    % approximate growth rate of arrival of ideas
    for i=1:15
        
        
        alUS0=(ga/(1-bt)*la_temp(iUS,1)) ...
            /(Ga2/Ga1*(PI_NT_t(iUS,1).*la_temp(iUS,1).^bt...
            +(PI_T(iUS,:)*ones(N,1)).^bt.*(PI_T(iUS,:).^(1-bt)*la_temp(:,1).^bt)));
        
        ganew=log(alUS(end)/alUS0)/(T-1);
        diff=abs(ga-ganew);
        
        [i ga ganew diff ga_low ga_high]
        
        if ganew>ga
            ga_low=ga;
            ga=.5*ga_low+.5*ga_high;
        else
            ga_high=ga;
            ga=.5*ga_low+.5*ga_high;
        end
        
        
    end
    
    laUS(ibt,:)=la_temp2(iUS,:);
    alUS0_bt(ibt)=alUS0;
    alUS_bt(ibt,:)=alUS;
    
    ga_bt(ibt)=ga;
    
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                             simulations                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% factor by which own expenditure share are lower in the more opened
% counterfactuals
a=.9;

miracles=[iChina iKorea iTaiwan iThailand];
% miracles=[iChina iKorea iTaiwan iThailand iCanada iParaguay iPortugal iSpain];

PI=reshape(PI_t(:,1),N,N);

% gridbt=[0];

Lt=L(:,1);

TFP_la=y(:,1);

% simulate for various values of beta
for ibt=1:Ibt
    
    PI=reshape(PI_t(:,1),N,N);
    
    bt=gridbt(ibt);
    
    %     ga=gUS*(1-bt)*th;
    
    % pull gamma from previously calibrated values
    ga=ga_bt(ibt);
    gUS_bt(ibt)=ga/(th*(1-bt));
    
    Ga2=gamma(1-bt+(1-ep)/th);
    
    % calculate initial alpha
    al0=ga/(1-bt)*Ga1/Ga2*la0...
        ./((1-mu)./(1-mu+mu*Z(:,1).^(-(ep-1)/th)).*la0.^bt...
        +mu*Z(:,1).^(-(ep-1)/th)./(1-mu+mu*Z(:,1).^(-(ep-1)/th))...
        .*(Z(:,1).^(1-bt).*la0.^bt+(1-Z(:,1)).^(1-bt)...
        .*(((PI-diag(diag(PI)))./(1-diag(PI)*ones(1,N))).^(1-bt)*la0.^bt)));
    
    
    % calculate initial lambda
    lat(:,1)=la0;
    
    lat_cal(:,1)=(y(:,t)).^((1-et)*th)./(Ga1^(th/(ep-1)).*(1-mu+mu*Z(:,t).^(-(ep-1)/th)).^(th/(ep-1)));
    
    % initialize lambda for counterfactual with fixed exposure
    lat_exp_fixed_all(:,1)=la0;
    
    %
    numsims = 4;
    
    for s = 1:numsims
        % s = 1: dummy simulation
        % s = 2: holding kappa_{ij,t} = kappa{ij,1}
        % s = 3: holding alpha_{ij,t} = alpha{i0}
        % s = 4: final dummy simulation
        
        if s == 3
            lat(:,1)=la0;
            lat_lafixed(:,1)=la0;
            lat_pifixed(:,1)=la0;
            lat_exp_fixed(:,1)=la0;
        end
        
        for t=1:T
            
            PI_T=reshape(PI_T_t(:,t),N,N);
            
            la=lat(:,t);
            % la=lat_true(:,t);
            
            if s == 2
                % holding kappa_{ij,t} = kappa{ij,1}
                K=reshape(KK(:,1),N,N);
            else
                % using calibrated evolution of trade costs
                K=reshape(KK(:,t),N,N);
            end
            
            % initial price index
            pini=Ga1^(1/(1-ep)/(1-et))*(ones(N,1).^(-(1-et)*th)'*la)^(1/(1-et))*ones(N,1);
            
            toler=.0001;
            imax=100;
            
            % approximate wage and price using algorthm from Alvarez and
            % Lucas, JME (2007)
            if t==1
                % w_d1(:,t)=wage(w_s(:,t),K,la,L(:,t));
                w_d1(:,t)=wage_T(ones(N,1),K,la,Lt(:,t),Tr(:,t));
                p_d1(:,t)=price(w_d1(:,t),pini,K,la);
            else
                % w_d1(:,t)=wage(w_d1(:,t-1),K,la,L(:,t));
                w_d1(:,t)=wage_T(w_d1(:,t-1),K,la,Lt(:,t),Tr(:,t));
                p_d1(:,t)=price(w_d1(:,t),p_d1(:,t-1),K,la);
            end
            
            % calculate own trade share
            den0=(1-mu)*((p_d1(:,t).^et.*w_d1(:,t).^(1-et)).^(-th).*la).^(-(1-ep)/th)...
                +mu*(K.^-th*((p_d1(:,t).^et.*w_d1(:,t).^(1-et)).^(-th).*la)).^(-(1-ep)/th);
            den=den0*ones(1,N);
            
            numT=mu*(((ones(N,1)*(p_d1(:,t).^et.*w_d1(:,t).^(1-et).*la.^(-1/th))').*K).^(-th))...
                .*((K.^-th*((p_d1(:,t).^et.*w_d1(:,t).^(1-et)).^(-th).*la)).^(-(1-ep)/th-1)*ones(1,N));
            
            numNT=(1-mu)*((p_d1(:,t).^et.*w_d1(:,t).^(1-et)).^(-th).*la).^(-(1-ep)/th);
            
            piT=numT./den;
            
            piNT=numNT./den0;
            pi_ii=piNT+diag(piT);
            
            if t==1
                temp=piNT.*la.^bt...
                    +(piT*ones(N,1)).^bt.*(piT.^(1-bt)*la.^bt);
                OmNT=piNT.*la.^bt./temp;
                OmT=((piT*ones(N,1)).^bt*(la.^bt)').*piT.^(1-bt)./(temp*ones(1,N));
                A=(1/((1-et)*th))*(1./(1-bt*(OmNT+diag(OmT))));
                % tradables own share
                piT_1=piT;
                % non-tradables share
                piNT_1=piNT;
                % own trade share
                pi_ii_1=pi_ii;
                % lambda_{it}
                la_1=la;
                
                if s==3
                    
                    i_m_1=0;
                    
                    for i_miracle=miracles
                        
                        i_m_1=i_m_1+1;
                        
                        ii_miracle=[1:i_miracle-1 i_miracle+1:N];
                        
                        b=(1-piNT(i_miracle)-a*piT(i_miracle,i_miracle)) ...
                            /(piT(i_miracle,ii_miracle)*ones(N-1,1));
                        
                        la_mo_l=.5*la0(i_miracle);
                        la_mo_h=10*la0(i_miracle);
                        la_mo(i_m_1,1)=.5*la_mo_l+.5*la_mo_h;
                        
                        for i_temp=1:40
                            
                            f_mo(i_m_1,1)=Ga2/Ga1*al0(i_miracle).*(piNT(i_miracle).*la_mo(i_m_1).^bt...
                                +(a*piT(i_miracle,i_miracle)+b*piT(i_miracle,ii_miracle)*ones(N-1,1)).^bt ...
                                .*((a*piT(i_miracle,i_miracle)).^(1-bt)*la_mo(i_m_1).^bt ...
                                +(b*piT(i_miracle,ii_miracle)).^(1-bt)*la0(ii_miracle).^bt) )...
                                -ga/(1-bt)*la_mo(i_m_1);
                            
                            if f_mo(i_m_1,1)>0
                                la_mo_l=la_mo(i_m_1);
                                la_mo(i_m_1,1)=.5*la_mo_l+.5*la_mo_h;
                            else
                                la_mo_h=la_mo(i_m_1);
                                la_mo(i_m_1,1)=.5*la_mo_l+.5*la_mo_h;
                            end
                            
                        end
                        
                    end
                    
                    la_China_mo(ibt,1)=la_mo(1);
                    la_Korea_mo(ibt,1)=la_mo(2);
                    la_Taiwan_mo(ibt,1)=la_mo(3);
                    la_Thailand_mo(ibt,1)=la_mo(4);
                    %                     la_Canada_mo(ibt,1)=la_mo(5);
                    %                     la_Paraguay_mo(ibt,1)=la_mo(6);
                    %                     la_Portugal_mo(ibt,1)=la_mo(7);
                    %                     la_Spain_mo(ibt,1)=la_mo(8);
                    
                    
                end
                
            end
            
            if t==T
                % tradables own share
                piT_T=piT;
                % non-tradables share
                piNT_T=piNT;
                % own trade share
                pi_ii_T=pi_ii;
                % lambda_{it}
                la_T=la;
            end
            
            % learning from sellers
            if t<T
                if s == 1
                    
                    if t==0 % ignoring this line
                        
                        al_t(:,t)=al0;
                        
                    else
                        
                        lat_cal(:,t+1)=(y(:,t+1)/exp(gUS_bt(ibt)*(t-1))).^((1-et)*th)./(Ga1^(th/(ep-1)).*(1-mu+mu*Z(:,t+1).^(-(ep-1)/th)).^(th/(ep-1)));
                        
                        % calculating value of alpha required to account
                        % for the residual  evolution of the stock of
                        % knowledge. Notice that we restrict the sequence
                        % of alphas to be positive.
                        al_t(:,t)=max(0,(lat_cal(:,t+1)-(1-ga/(1-bt))*lat(:,t)) ...
                            /(Ga2/Ga1)./(piNT.*lat(:,t).^bt...
                            +(piT*ones(N,1)).^bt.*(piT.^(1-bt)*lat(:,t).^bt)));
                        
                    end
                    
                    % if alpha is constrained, we adjust the evolution of
                    % the stock of knowledge to be consistent with the
                    % constrained series of alpha
                    lat(:,t+1)=Ga2/Ga1*al_t(:,t).*(piNT.*lat(:,t).^bt...
                        +(piT*ones(N,1)).^bt.*(piT.^(1-bt)*lat(:,t).^bt))+(1-ga/(1-bt))*lat(:,t);
                    % the residual evolution of TFP is assinged to an
                    % exogenous component
                    TFP_la(:,t+1)=(Ga1^(th/(ep-1))*lat(:,t+1).*(1-mu+mu*Z(:,t+1).^(-(ep-1)/th)).^(th/(ep-1))).^(1/((1-et)*th));
                    % and the series of the equipped units of labor are
                    % adjusted accordingly
                    Lt(:,t+1)=y(:,t+1)./TFP_la(:,t+1).*L(:,t+1);
                    
                    % calculate counterfactual evolution of lambda when own expenditure
                    % shares evolve as in the benchmark simulation, but the
                    % relative expendidute share in imported goods equals the
                    % initial one
                    temp=(piT_1-diag(diag(piT_1))); % expenditure share of tradables minus the share of own tradables
                    adj=(1-piNT-diag(piT))./(sum(temp')'); % adjustment factor
                    % needed for counterfactual expenditure shares to add up to one
                    piTtemp=diag(diag(piT))+temp.*(adj*ones(1,N));
                    lat_exp_fixed_all(:,t+1)=Ga2/Ga1*al_t(:,t).*(piNT.*lat_exp_fixed_all(:,t).^bt...
                        +(piTtemp*ones(N,1)).^bt.*((piTtemp.^(1-bt).*(diag(lat_exp_fixed_all(:,t))+ones(N,1)*la'-diag(la)).^bt)*ones(N,1)))...
                        +(1-ga/(1-bt))*lat_exp_fixed_all(:,t);
                    
                elseif s == 3
                    
                    % counterfactual evolution of the stock of knowledge
                    % when the arrival rate of ideas is kept constant at
                    % its initial value
                    lat(:,t+1)=Ga2/Ga1*al0.*(piNT.*lat(:,t).^bt...
                        +(piT*ones(N,1)).^bt.*(piT.^(1-bt)*lat(:,t).^bt))+(1-ga/(1-bt))*lat(:,t);
                    
                    lat_lafixed(:,t+1)=Ga2/Ga1*al0.*(piNT.*lat_lafixed(:,t).^bt...
                        +(piT*ones(N,1)).^bt.*((piT.^(1-bt).*(diag(lat_lafixed(:,t))+ones(N,1)*la_1'-diag(la_1)).^bt)*ones(N,1)))...
                        +(1-ga/(1-bt))*lat_lafixed(:,t);
                    
                    lat_pifixed(:,t+1)=Ga2/Ga1*al0.*(piNT_1.*lat_pifixed(:,t).^bt...
                        +(piT_1*ones(N,1)).^bt.*((piT_1.^(1-bt).*(diag(lat_pifixed(:,t))+ones(N,1)*la'-diag(la)).^bt)*ones(N,1)))...
                        +(1-ga/(1-bt))*lat_pifixed(:,t);
                    
                    % calculate counterfactual evolution of lambda when own expenditure
                    % shares evolve as in the benchmark simulation, but the
                    % relative expendidute share in imported goods equals the
                    % initial one
                    temp=(piT_1-diag(diag(piT_1))); % expenditure share of tradables minus the share of own tradables
                    adj=(1-piNT-diag(piT))./(sum(temp')'); % adjustment factor
                    % needed for counterfactual expenditure shares to add up to one
                    piTtemp=diag(diag(piT))+temp.*(adj*ones(1,N));
                    lat_exp_fixed(:,t+1)=Ga2/Ga1*al0.*(piNT.*lat_exp_fixed(:,t).^bt...
                        +(piTtemp*ones(N,1)).^bt.*((piTtemp.^(1-bt).*(diag(lat_exp_fixed(:,t))+ones(N,1)*la'-diag(la)).^bt)*ones(N,1)))...
                        +(1-ga/(1-bt))*lat_exp_fixed(:,t);
                    
                    % calculate counterfactual evolution of the stock of
                    % ideas of miracle economies if they would have been
                    % proportionally more opened.
                    iiChina=[1:iChina-1 iChina+1:N];
                    b=(1-piNT(iChina)-a*piT(iChina,iChina)) ...
                        /(piT(iChina,iiChina)*ones(N-1,1));
                    
                    la_China_mo(ibt,t+1)=Ga2/Ga1*al0(iChina).*(piNT(iChina).*la_China_mo(ibt,t).^bt...
                        +(a*piT(iChina,iChina)+b*piT(iChina,iiChina)*ones(N-1,1)).^bt ...
                        .*((a*piT(iChina,iChina)).^(1-bt)*la_China_mo(ibt,t).^bt ...
                        +(b*piT(iChina,iiChina)).^(1-bt)*la0(iiChina).^bt) )...
                        +(1-ga/(1-bt))*la_China_mo(ibt,t);
                    
                    iiKorea=[1:iKorea-1 iKorea+1:N];
                    b=(1-piNT(iKorea)-a*piT(iKorea,iKorea)) ...
                        /(piT(iKorea,iiKorea)*ones(N-1,1));
                    
                    la_Korea_mo(ibt,t+1)=Ga2/Ga1*al0(iKorea).*(piNT(iKorea).*la_Korea_mo(ibt,t).^bt...
                        +(a*piT(iKorea,iKorea)+b*piT(iKorea,iiKorea)*ones(N-1,1)).^bt ...
                        .*((a*piT(iKorea,iKorea)).^(1-bt)*la_Korea_mo(ibt,t).^bt ...
                        +(b*piT(iKorea,iiKorea)).^(1-bt)*la0(iiKorea).^bt) )...
                        +(1-ga/(1-bt))*la_Korea_mo(ibt,t);
                    
                    iiTaiwan=[1:iTaiwan-1 iTaiwan+1:N];
                    b=(1-piNT(iTaiwan)-a*piT(iTaiwan,iTaiwan)) ...
                        /(piT(iTaiwan,iiTaiwan)*ones(N-1,1));
                    
                    la_Taiwan_mo(ibt,t+1)=Ga2/Ga1*al0(iTaiwan).*(piNT(iTaiwan).*la_Taiwan_mo(ibt,t).^bt...
                        +(a*piT(iTaiwan,iTaiwan)+b*piT(iTaiwan,iiTaiwan)*ones(N-1,1)).^bt ...
                        .*((a*piT(iTaiwan,iTaiwan)).^(1-bt)*la_Taiwan_mo(ibt,t).^bt ...
                        +(b*piT(iTaiwan,iiTaiwan)).^(1-bt)*la0(iiTaiwan).^bt) )...
                        +(1-ga/(1-bt))*la_Taiwan_mo(ibt,t);
                    
                    iiThailand=[1:iThailand-1 iThailand+1:N];
                    b=(1-piNT(iThailand)-a*piT(iThailand,iThailand)) ...
                        /(piT(iThailand,iiThailand)*ones(N-1,1));
                    
                    la_Thailand_mo(ibt,t+1)=Ga2/Ga1*al0(iThailand).*(piNT(iThailand).*la_Thailand_mo(ibt,t).^bt...
                        +(a*piT(iThailand,iThailand)+b*piT(iThailand,iiThailand)*ones(N-1,1)).^bt ...
                        .*((a*piT(iThailand,iThailand)).^(1-bt)*la_Thailand_mo(ibt,t).^bt ...
                        +(b*piT(iThailand,iiThailand)).^(1-bt)*la0(iiThailand).^bt) )...
                        +(1-ga/(1-bt))*la_Thailand_mo(ibt,t);
                    
                else
                    
                    lat(:,t+1)=Ga2/Ga1*al_t(:,t).*(piNT.*lat(:,t).^bt...
                        +(piT*ones(N,1)).^bt.*(piT.^(1-bt)*lat(:,t).^bt))+(1-ga/(1-bt))*lat(:,t);
                    
                    
                end
            end
            
            pi_ii_d1(:,t)=pi_ii;
            
            pi_la(:,t)=(diag(piNT)+piT)*la;
            pi_la0(:,t)=(diag(piNT)+piT)*la0;
            
            if s==3
                
                [Z_China_al0(ibt,t)]=fminbnd('eq_Z_pi',0,1,[],pi_ii(iChina));
                [Z_Korea_al0(ibt,t)]=fminbnd('eq_Z_pi',0,1,[],pi_ii(iKorea));
                [Z_Taiwan_al0(ibt,t)]=fminbnd('eq_Z_pi',0,1,[],pi_ii(iTaiwan));
                [Z_Thailand_al0(ibt,t)]=fminbnd('eq_Z_pi',0,1,[],pi_ii(iThailand));
                [Z_Canada_al0(ibt,t)]=fminbnd('eq_Z_pi',0,1,[],pi_ii(iCanada));
                [Z_Paraguay_al0(ibt,t)]=fminbnd('eq_Z_pi',0,1,[],pi_ii(iParaguay));
                [Z_Portugal_al0(ibt,t)]=fminbnd('eq_Z_pi',0,1,[],pi_ii(iPortugal));
                [Z_Spain_al0(ibt,t)]=fminbnd('eq_Z_pi',0,1,[],pi_ii(iSpain));
                
                TFP_China_exp_fixed(ibt,t)=(lat_exp_fixed(iChina,t).*(1-mu+mu*Z_China_al0(ibt,t).^(-(ep-1)/th)).^(th/(ep-1))).^(1/((1-et)*th));
                TFP_Korea_exp_fixed(ibt,t)=(lat_exp_fixed(iKorea,t).*(1-mu+mu*Z_Korea_al0(ibt,t).^(-(ep-1)/th)).^(th/(ep-1))).^(1/((1-et)*th));
                TFP_Taiwan_exp_fixed(ibt,t)=(lat_exp_fixed(iTaiwan,t).*(1-mu+mu*Z_Taiwan_al0(ibt,t).^(-(ep-1)/th)).^(th/(ep-1))).^(1/((1-et)*th));
                TFP_Thailand_exp_fixed(ibt,t)=(lat_exp_fixed(iThailand,t).*(1-mu+mu*Z_Thailand_al0(ibt,t).^(-(ep-1)/th)).^(th/(ep-1))).^(1/((1-et)*th));
                TFP_Canada_exp_fixed(ibt,t)=(lat_exp_fixed(iCanada,t).*(1-mu+mu*Z_Canada_al0(ibt,t).^(-(ep-1)/th)).^(th/(ep-1))).^(1/((1-et)*th));
                TFP_Paraguay_exp_fixed(ibt,t)=(lat_exp_fixed(iParaguay,t).*(1-mu+mu*Z_Paraguay_al0(ibt,t).^(-(ep-1)/th)).^(th/(ep-1))).^(1/((1-et)*th));
                TFP_Portugal_exp_fixed(ibt,t)=(lat_exp_fixed(iPortugal,t).*(1-mu+mu*Z_Portugal_al0(ibt,t).^(-(ep-1)/th)).^(th/(ep-1))).^(1/((1-et)*th));
                TFP_Spain_exp_fixed(ibt,t)=(lat_exp_fixed(iSpain,t).*(1-mu+mu*Z_Spain_al0(ibt,t).^(-(ep-1)/th)).^(th/(ep-1))).^(1/((1-et)*th));
                
                TFP_China_mo(ibt,t)=(la_China_mo(ibt,t).*(1-mu+mu*(a*Z_China_al0(ibt,t)).^(-(ep-1)/th)).^(th/(ep-1))).^(1/((1-et)*th));
                TFP_Korea_mo(ibt,t)=(la_Korea_mo(ibt,t).*(1-mu+mu*(a*Z_Korea_al0(ibt,t)).^(-(ep-1)/th)).^(th/(ep-1))).^(1/((1-et)*th));
                TFP_Taiwan_mo(ibt,t)=(la_Taiwan_mo(ibt,t).*(1-mu+mu*(a*Z_Taiwan_al0(ibt,t)).^(-(ep-1)/th)).^(th/(ep-1))).^(1/((1-et)*th));
                TFP_Thailand_mo(ibt,t)=(la_Thailand_mo(ibt,t).*(1-mu+mu*(a*Z_Thailand_al0(ibt,t)).^(-(ep-1)/th)).^(th/(ep-1))).^(1/((1-et)*th));
                
            end
            
        end
        
        % save unique items depending on simulation
        if s == 1
            for i=1:N
                [Z_0_all(i,ibt)]=fminbnd('eq_Z_pi',0,1,[],pi_ii_1(i));
                [Z_T_all(i,ibt)]=fminbnd('eq_Z_pi',0,1,[],pi_ii_T(i));
            end
            TFP0_all_Z(:,ibt)=(lat(:,1).*(1-mu+mu*Z_0_all(:,ibt).^(-(ep-1)/th)).^(th/(ep-1))).^(1/((1-et)*th));
            TFPT_all_Z(:,ibt)=(lat(:,T).*(1-mu+mu*Z_T_all(:,ibt).^(-(ep-1)/th)).^(th/(ep-1))).^(1/((1-et)*th));
            
            TFP0_exp_fixed_all_Z(:,ibt)=(lat_exp_fixed_all(:,1).*(1-mu+mu*Z_0_all(:,ibt).^(-(ep-1)/th)).^(th/(ep-1))).^(1/((1-et)*th));
            TFPT_exp_fixed_all_Z(:,ibt)=(lat_exp_fixed_all(:,T).*(1-mu+mu*Z_T_all(:,ibt).^(-(ep-1)/th)).^(th/(ep-1))).^(1/((1-et)*th));
            
            pi_ii_0_all(:,ibt)=pi_ii_1;
            pi_ii_T_all(:,ibt)=pi_ii_T;
            
            piT_0_all(:,ibt)=reshape(piT_1,N*N,1);
            piT_T_all(:,ibt)=reshape(piT_T,N*N,1);
            piNT_0_all(:,ibt)=piNT_1;
            piNT_T_all(:,ibt)=piNT_T;
            
            la0_all(:,ibt)=lat(:,1);
            laT_all(:,ibt)=lat(:,T);
            
            TFP0_all(:,ibt)=(w_d1(:,1)./p_d1(:,1));
            TFPT_all(:,ibt)=(w_d1(:,end)./p_d1(:,end));
            dTFP_all(:,ibt)=log((w_d1(:,end)./p_d1(:,end))./(w_d1(:,1)./p_d1(:,1)));
            
            MSE_all(ibt)=mean((log(y(:,T)./y(:,1)/exp(gUS*(T-1)))-mean(log(y(:,T)./y(:,1)/exp(gUS*(T-1))))...
                -(dTFP_all(:,ibt)-mean(dTFP_all(:,ibt)))).^2)^.5;
            
            TFP_Korea_all(ibt,:)=w_d1(iKorea,:)./p_d1(iKorea,:);
            TFP_China_all(ibt,:)=w_d1(iChina,:)./p_d1(iChina,:);
            TFP_Taiwan_all(ibt,:)=w_d1(iTaiwan,:)./p_d1(iTaiwan,:);
            TFP_Thailand_all(ibt,:)=w_d1(iThailand,:)./p_d1(iThailand,:);
            TFP_Canada_all(ibt,:)=w_d1(iCanada,:)./p_d1(iCanada,:);
            TFP_Paraguay_all(ibt,:)=w_d1(iParaguay,:)./p_d1(iParaguay,:);
            TFP_Portugal_all(ibt,:)=w_d1(iPortugal,:)./p_d1(iPortugal,:);
            TFP_Spain_all(ibt,:)=w_d1(iSpain,:)./p_d1(iSpain,:);
            
            TFP_US_all(ibt,:)=w_d1(iUS,:)./p_d1(iUS,:);
            
            lat(:,1)=la0;
            
        elseif s == 2
            for i=1:N
                [Z_0_k0(i,ibt)]=fminbnd('eq_Z_pi',0,1,[],pi_ii_1(i));
                [Z_T_k0(i,ibt)]=fminbnd('eq_Z_pi',0,1,[],pi_ii_T(i));
            end
            TFP0_k0_Z(:,ibt)=(lat(:,1).*(1-mu+mu*Z_0_k0(:,ibt).^(-(ep-1)/th)).^(th/(ep-1))).^(1/((1-et)*th));
            TFPT_k0_Z(:,ibt)=(lat(:,T).*(1-mu+mu*Z_T_k0(:,ibt).^(-(ep-1)/th)).^(th/(ep-1))).^(1/((1-et)*th));
            
            pi_ii_0_k0(:,ibt)=pi_ii_1;
            pi_ii_T_k0(:,ibt)=pi_ii_T;
            la0_k0(:,ibt)=lat(:,1);
            laT_k0(:,ibt)=lat(:,T);
            
            piT_0_ka0(:,ibt)=reshape(piT_1,N*N,1);
            piT_T_ka0(:,ibt)=reshape(piT_T,N*N,1);
            piNT_0_ka0(:,ibt)=piNT_1;
            piNT_T_ka0(:,ibt)=piNT_T;
            
            TFP0_k0(:,ibt)=(w_d1(:,1)./p_d1(:,1));
            TFPT_k0(:,ibt)=(w_d1(:,end)./p_d1(:,end));
            dTFP_k0(:,ibt)=log((w_d1(:,end)./p_d1(:,end))./(w_d1(:,1)./p_d1(:,1)));
            
            %     MSE(ibt)=mean((log(y(:,T)./y(:,1)/exp(gUS*(T-1)))-mean(log(y(:,T)./y(:,1)/exp(gUS*(T-1))))...
            %         -(dTFP(:,ibt)-mean(dTFP(:,ibt)))).^2)^.5;
            
            MSE_k0(ibt)=mean(((dTFP_all(:,ibt)-mean(dTFP_all(:,ibt)))...
                -(dTFP_k0(:,ibt)-mean(dTFP_k0(:,ibt)))).^2)^.5;
            
            TFP_Korea_k0(ibt,:)=w_d1(iKorea,:)./p_d1(iKorea,:);
            TFP_China_k0(ibt,:)=w_d1(iChina,:)./p_d1(iChina,:);
            TFP_Taiwan_k0(ibt,:)=w_d1(iTaiwan,:)./p_d1(iTaiwan,:);
            TFP_Thailand_k0(ibt,:)=w_d1(iThailand,:)./p_d1(iThailand,:);
            TFP_Canada_k0(ibt,:)=w_d1(iCanada,:)./p_d1(iCanada,:);
            TFP_Paraguay_k0(ibt,:)=w_d1(iParaguay,:)./p_d1(iParaguay,:);
            TFP_Portugal_k0(ibt,:)=w_d1(iPortugal,:)./p_d1(iPortugal,:);
            TFP_Spain_k0(ibt,:)=w_d1(iSpain,:)./p_d1(iSpain,:);
            
            TFP_US_k0(ibt,:)=w_d1(iUS,:)./p_d1(iUS,:);
            
            [ibt MSE_all(ibt) MSE_k0(ibt)]
            
        elseif s == 3
            for i=1:N
                [Z_0_al0(i,ibt)]=fminbnd('eq_Z_pi',0,1,[],pi_ii_1(i));
                [Z_T_al0(i,ibt)]=fminbnd('eq_Z_pi',0,1,[],pi_ii_T(i));
            end
            
            TFP_fixed_la(:,ibt)=(Ga1^(th/(ep-1))*lat_lafixed(:,t).*(1-mu+mu*Z_0_al0(:,ibt).^(-(ep-1)/th)).^(th/(ep-1))).^(1/((1-et)*th));
            TFP_fixed_pi(:,ibt)=(Ga1^(th/(ep-1))*lat_pifixed(:,t).*(1-mu+mu*Z_0_al0(:,ibt).^(-(ep-1)/th)).^(th/(ep-1))).^(1/((1-et)*th));
            
            TFP0_al0_Z(:,ibt)=(lat(:,1).*(1-mu+mu*Z_0_al0(:,ibt).^(-(ep-1)/th)).^(th/(ep-1))).^(1/((1-et)*th));
            TFPT_al0_Z(:,ibt)=(lat(:,T).*(1-mu+mu*Z_T_al0(:,ibt).^(-(ep-1)/th)).^(th/(ep-1))).^(1/((1-et)*th));
            
            TFP0_exp_fixed_Z(:,ibt)=(lat_exp_fixed(:,1).*(1-mu+mu*Z_0_al0(:,ibt).^(-(ep-1)/th)).^(th/(ep-1))).^(1/((1-et)*th));
            TFPT_exp_fixed_Z(:,ibt)=(lat_exp_fixed(:,T).*(1-mu+mu*Z_T_al0(:,ibt).^(-(ep-1)/th)).^(th/(ep-1))).^(1/((1-et)*th));
            
            pi_ii_0_al0(:,ibt)=pi_ii_1;
            pi_ii_T_al0(:,ibt)=pi_ii_T;
            la0_al0(:,ibt)=lat(:,1);
            laT_al0(:,ibt)=lat(:,T);
            
            piT_0_al0(:,ibt)=reshape(piT_1,N*N,1);
            piT_T_al0(:,ibt)=reshape(piT_T,N*N,1);
            piNT_0_al0(:,ibt)=piNT_1;
            piNT_T_al0(:,ibt)=piNT_T;
            
            TFP0_al0(:,ibt)=(w_d1(:,1)./p_d1(:,1));
            TFPT_al0(:,ibt)=(w_d1(:,end)./p_d1(:,end));
            dTFP_al0(:,ibt)=log((w_d1(:,end)./p_d1(:,end))./(w_d1(:,1)./p_d1(:,1)));
            
            %     MSE(ibt)=mean((log(y(:,T)./y(:,1)/exp(gUS*(T-1)))-mean(log(y(:,T)./y(:,1)/exp(gUS*(T-1))))...
            %         -(dTFP(:,ibt)-mean(dTFP(:,ibt)))).^2)^.5;
            
            MSE_al0(ibt)=mean(((dTFP_all(:,ibt)-mean(dTFP_all(:,ibt)))...
                -(dTFP_al0(:,ibt)-mean(dTFP_al0(:,ibt)))).^2)^.5;
            
            TFP_Korea_al0(ibt,:)=w_d1(iKorea,:)./p_d1(iKorea,:);
            TFP_China_al0(ibt,:)=w_d1(iChina,:)./p_d1(iChina,:);
            TFP_Taiwan_al0(ibt,:)=w_d1(iTaiwan,:)./p_d1(iTaiwan,:);
            TFP_Thailand_al0(ibt,:)=w_d1(iThailand,:)./p_d1(iThailand,:);
            TFP_Canada_al0(ibt,:)=w_d1(iCanada,:)./p_d1(iCanada,:);
            TFP_Paraguay_al0(ibt,:)=w_d1(iParaguay,:)./p_d1(iParaguay,:);
            TFP_Portugal_al0(ibt,:)=w_d1(iPortugal,:)./p_d1(iPortugal,:);
            TFP_Spain_al0(ibt,:)=w_d1(iSpain,:)./p_d1(iSpain,:);
            
            TFP_US_al0(ibt,:)=w_d1(iUS,:)./p_d1(iUS,:);
            
            [ibt MSE_all(ibt) MSE_al0(ibt)]
            
        elseif s == 4
            
            TFP0_all2(:,ibt)=(w_d1(:,1)./p_d1(:,1));
            TFPT_all2(:,ibt)=(w_d1(:,end)./p_d1(:,end));
            dTFP_all2(:,ibt)=log((w_d1(:,end)./p_d1(:,end))./(w_d1(:,1)./p_d1(:,1)));
            
            %     MSE(ibt)=mean((log(y(:,T)./y(:,1)/exp(gUS*(T-1)))-mean(log(y(:,T)./y(:,1)/exp(gUS*(T-1))))...
            %         -(dTFP(:,ibt)-mean(dTFP(:,ibt)))).^2)^.5;
            
            MSE_all2(ibt)=mean(((dTFP_all(:,ibt)-mean(dTFP_all(:,ibt)))...
                -(dTFP_all2(:,ibt)-mean(dTFP_all2(:,ibt)))).^2)^.5;
            
            alpha0(:,ibt)=al_t(:,1);
            alphaT(:,ibt)=al_t(:,end);
            
            [ibt MSE_all(ibt) MSE_all2(ibt)]
            
        end
    end
end


save trans_k0_al0_s_02_mu_34_exp_03 MSE_all TFP0_all TFPT_all dTFP_all TFP_Korea_all TFP_China_all TFP_Taiwan_all TFP_Thailand_all TFP_US_all ...
    MSE_k0 TFP0_k0 TFPT_k0 dTFP_k0 TFP_Korea_k0 TFP_China_k0 TFP_Taiwan_k0 TFP_Thailand_k0 TFP_US_k0 ...
    MSE_al0 TFP0_al0 TFPT_al0 dTFP_al0 TFP_Korea_al0 TFP_China_al0 TFP_Taiwan_al0 TFP_Thailand_al0 TFP_US_al0 alpha0 alphaT ...
    pi_ii_0_all pi_ii_T_all pi_ii_0_k0 pi_ii_T_k0 pi_ii_0_al0 pi_ii_T_al0 ...
    la0_all laT_all la0_k0 laT_k0 la0_al0 laT_al0 Z_0_all Z_T_all Z_0_k0 Z_T_k0 Z_0_al0 Z_T_al0 TFP_fixed_la TFP_fixed_pi ga_bt ...
    piT_0_ka0 piT_T_ka0 piNT_0_ka0 piNT_T_ka0 piT_0_al0 piT_T_al0 piNT_0_al0 piNT_T_al0 ...
    piT_0_all piT_T_all piNT_0_all piNT_T_all TFP_China_exp_fixed TFP_Korea_exp_fixed TFP_Taiwan_exp_fixed TFP_Thailand_exp_fixed TFP0_exp_fixed_Z TFPT_exp_fixed_Z ...
    pi_ii_data TFP0_exp_fixed_all_Z TFPT_exp_fixed_all_Z

% save trans_k0_al0_s_02_mu_34_exp_symK MSE_all TFP0_all TFPT_all dTFP_all TFP_Korea_all TFP_China_all TFP_Taiwan_all TFP_Thailand_all TFP_US_all ...
%     MSE_k0 TFP0_k0 TFPT_k0 dTFP_k0 TFP_Korea_k0 TFP_China_k0 TFP_Taiwan_k0 TFP_Thailand_k0 TFP_US_k0 ...
%     MSE_al0 TFP0_al0 TFPT_al0 dTFP_al0 TFP_Korea_al0 TFP_China_al0 TFP_Taiwan_al0 TFP_Thailand_al0 TFP_US_al0 alpha0 alphaT ...
%     pi_ii_0_all pi_ii_T_all pi_ii_0_k0 pi_ii_T_k0 pi_ii_0_al0 pi_ii_T_al0 ...
%     la0_all laT_all la0_k0 laT_k0 la0_al0 laT_al0 Z_0_all Z_T_all Z_0_k0 Z_T_k0 Z_0_al0 Z_T_al0 TFP_fixed_la TFP_fixed_pi ga_bt ...
%     piT_0_ka0 piT_T_ka0 piNT_0_ka0 piNT_T_ka0 piT_0_al0 piT_T_al0 piNT_0_al0 piNT_T_al0 ...
%     piT_0_all piT_T_all piNT_0_all piNT_T_all TFP_China_exp_fixed TFP_Korea_exp_fixed TFP_Taiwan_exp_fixed TFP_Thailand_exp_fixed

% save trans_k0_al0_s_02_mu_34_exp_reexports_in MSE_all TFP0_all TFPT_all dTFP_all TFP_Korea_all TFP_China_all TFP_Taiwan_all TFP_Thailand_all TFP_US_all ...
%     MSE_k0 TFP0_k0 TFPT_k0 dTFP_k0 TFP_Korea_k0 TFP_China_k0 TFP_Taiwan_k0 TFP_Thailand_k0 TFP_US_k0 ...
%     MSE_al0 TFP0_al0 TFPT_al0 dTFP_al0 TFP_Korea_al0 TFP_China_al0 TFP_Taiwan_al0 TFP_Thailand_al0 TFP_US_al0 alpha0 alphaT ...
%     pi_ii_0_all pi_ii_T_all pi_ii_0_k0 pi_ii_T_k0 pi_ii_0_al0 pi_ii_T_al0 ...
%     la0_all laT_all la0_k0 laT_k0 la0_al0 laT_al0 Z_0_all Z_T_all Z_0_k0 Z_T_k0 Z_0_al0 Z_T_al0 TFP_fixed_la TFP_fixed_pi ga_bt ...
%     piT_0_ka0 piT_T_ka0 piNT_0_ka0 piNT_T_ka0 piT_0_al0 piT_T_al0 piNT_0_al0 piNT_T_al0 ...
%     piT_0_all piT_T_all piNT_0_all piNT_T_all

ibt=6;

% data for Table 1 in the online supplementary appendix

TFP_table(:,1) = 1:N;
TFP_table(:,2) = log(TFPT_all(:,ibt) ./ TFP0_all(:,ibt));
TFP_table(:,3) = log(TFPT_al0(:,1) ./ TFP0_all(:,1));
TFP_table(:,4) = log(TFPT_al0(:,ibt) ./ TFP0_al0(:,ibt));
TFP_table(:,5) = log(TFPT_all(:,ibt) ./ TFPT_k0(:,ibt));
TFP_table(:,6) = pi_ii_data(:,1);
TFP_table(:,7) = pi_ii_data(:,end);
TFP_table(:,8) = log(TFPT_exp_fixed_Z(:,ibt)./TFP0_exp_fixed_Z(:,ibt));


[tfp_tbl(:,2), tfp_tbl_i] = sort(TFP_table(:,2),1,'descend');
tfp_tbl(:,1) = tfp_tbl_i;
tfp_tbl(:,3) = TFP_table(tfp_tbl_i,3);
tfp_tbl(:,4) = TFP_table(tfp_tbl_i,4);
tfp_tbl(:,5) = TFP_table(tfp_tbl_i,5);
tfp_tbl(:,6) = TFP_table(tfp_tbl_i,6);
tfp_tbl(:,7) = TFP_table(tfp_tbl_i,7);
tfp_tbl(:,8) = TFP_table(tfp_tbl_i,8);

save tfp_tbl.txt tfp_tbl -ascii

